==> nextcloud-25.0.5.tgz: nextcloud/apps/weather_status/l10n/fi.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Tuntematon osoite",
    "No result." : "Ei tuloksia.",
    "Malformed JSON data." : "Virheellinen JSON-data.",
    "Error" : "Virhe",
    "Weather status" : "Säätiedot",
    "Weather status in your dashboard" : "Säätiedot kojelaudassa",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Säätiedot integroituna kojelautaan.\n    Käyttäjän sijainti voidaan joko tunnistaa automaattisesti tai asettaa manuaalisesti. Sääennuste näytetään kuudelle tunnille.\n    Tiedot voidaan myös integroida muihin paikkoihin, kuten kalenterisovellukseen.",
    "Detect location" : "Tunnista sijainti",
    "Set custom address" : "Syötä osoite",
    "Favorites" : "Suosikit",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} selkeä taivas myöhemmin tänään",
    "{temperature} {unit} clear sky" : "{temperature} {unit} selkeä taivas",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} pilvistä myöhemmin tänään",
    "{temperature} {unit} cloudy" : "{temperature} {unit} pilvistä",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} poutaa myöhemmin tänään",
    "{temperature} {unit} fair weather" : "{temperature} {unit} poutaa",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} puolipilvistä myöhemmin tänään",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} puolipilvistä",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} sumuista myöhemmin tänään",
    "{temperature} {unit} foggy" : "{temperature} {unit} sumuista",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} kevyt sadekuuro myöhemmin tänään",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} kevyt sadekuuro",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} sadekuuro myöhemmin tänään",
    "{temperature} {unit} rainfall" : "{temperature} {unit} sadekuuro",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} rankka sadekuuro myöhemmin tänään",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} rankka sadekuuro",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} sadekuuroja myöhemmin tänään",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} sadekuuroja",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} kevyitä sadekuuroja myöhemmin tänään",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} kevyitä sadekuuroja",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} rankkoja sadekuuroja myöhemmin tänään",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} rankkoja sadekuuroja",
    "More weather for {adr}" : "Lisää säätietoja kohteesta {adr}",
    "Loading weather" : "Ladataan säätietoa",
    "Remove from favorites" : "Poista suosikeista",
    "Add as favorite" : "Lisää suosikiksi",
    "You are not logged in." : "Et ole kirjautuneena sisään.",
    "There was an error getting the weather status information." : "Säätietojen noudossa tapahtui virhe.",
    "No weather information found" : "Säätietoja ei löytynyt",
    "Location not found" : "Sijaintia ei löytynyt",
    "There was an error setting the location address." : "Sijainnin osoitteen asettamisessa tapahtui virhe.",
    "There was an error setting the location." : "Sijainnin asettamisessa tapahtui virhe.",
    "There was an error saving the mode." : "Tilan tallennuksessa tapahtui virhe.",
    "There was an error using personal address." : "Henkilökohtaisen osoitteen käytössä tapahtui virhe.",
    "Set location for weather" : "Aseta sijainti säätiedoille"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/weather_status/l10n/fi.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Tuntematon osoite",
    "No result." : "Ei tuloksia.",
    "Malformed JSON data." : "Virheellinen JSON-data.",
    "Error" : "Virhe",
    "Weather status" : "Säätiedot",
    "Weather status in your dashboard" : "Säätiedot kojelaudassa",
    "Detect location" : "Tunnista sijainti",
    "Set custom address" : "Syötä osoite",
    "Favorites" : "Suosikit",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} selkeä taivas myöhemmin tänään",
    "{temperature} {unit} clear sky" : "{temperature} {unit} selkeä taivas",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} pilvistä myöhemmin tänään",
    "{temperature} {unit} cloudy" : "{temperature} {unit} pilvistä",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} poutaa myöhemmin tänään",
    "{temperature} {unit} fair weather" : "{temperature} {unit} poutaa",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} puolipilvistä myöhemmin tänään",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} puolipilvistä",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} sumuista myöhemmin tänään",
    "{temperature} {unit} foggy" : "{temperature} {unit} sumuista",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} kevyt sadekuuro myöhemmin tänään",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} kevyt sadekuuro",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} sadekuuro myöhemmin tänään",
    "{temperature} {unit} rainfall" : "{temperature} {unit} sadekuuro",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} rankka sadekuuro myöhemmin tänään",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} rankka sadekuuro",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} sadekuuroja myöhemmin tänään",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} sadekuuroja",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} kevyitä sadekuuroja myöhemmin tänään",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} kevyitä sadekuuroja",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} rankkoja sadekuuroja myöhemmin tänään",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} rankkoja sadekuuroja",
    "More weather for {adr}" : "Lisää säätietoja kohteesta {adr}",
    "Loading weather" : "Ladataan säätietoa",
    "Remove from favorites" : "Poista suosikeista",
    "Add as favorite" : "Lisää suosikiksi",
    "You are not logged in." : "Et ole kirjautuneena sisään.",
    "There was an error getting the weather status information." : "Säätietojen noudossa tapahtui virhe.",
    "No weather information found" : "Säätietoja ei löytynyt",
    "Location not found" : "Sijaintia ei löytynyt",
    "There was an error setting the location address." : "Sijainnin osoitteen asettamisessa tapahtui virhe.",
    "There was an error setting the location." : "Sijainnin asettamisessa tapahtui virhe.",
    "There was an error saving the mode." : "Tilan tallennuksessa tapahtui virhe.",
    "There was an error using personal address." : "Henkilökohtaisen osoitteen käytössä tapahtui virhe.",
    "Set location for weather" : "Aseta sijainti säätiedoille",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Säätiedot integroituna kojelautaan.\n    Käyttäjän sijainti voidaan joko tunnistaa automaattisesti tai asettaa manuaalisesti. Sääennuste näytetään kuudelle tunnille.\n    Tiedot voidaan myös integroida muihin paikkoihin, kuten kalenterisovellukseen."
},
"nplurals=2; plural=(n != 1);");
